==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/plugins/General/fileops/translations/fileops_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>目標目錄早已存在</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="104"/>
        <source>Copying</source>
        <translation>正在復制</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="105"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="146"/>
        <source>Copying file %1/%2</source>
        <translation>復制檔案 %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="189"/>
        <source>Remove files</source>
        <translation>刪除檔案</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="190"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>檔案操作插件</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>關於檔案操作插件</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Qmmp 檔案操作插件</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>修改熱鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>請按您想指定的組合鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Copy</source>
        <translation>復制</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="55"/>
        <location filename="../settingsdialog.cpp" line="135"/>
        <source>Remove</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="138"/>
        <source>New action</source>
        <translation>新動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="192"/>
        <source>Artist</source>
        <translation>藝術家</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="193"/>
        <source>Album</source>
        <translation>專輯</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="194"/>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="197"/>
        <source>Genre</source>
        <translation>流派</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="204"/>
        <source>Year</source>
        <translation>年代</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="198"/>
        <source>Comment</source>
        <translation>備註</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Track number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="196"/>
        <source>Two-digit track number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="199"/>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="200"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="201"/>
        <source>Disc number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="202"/>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="203"/>
        <source>File path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="205"/>
        <source>Condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Choose a directory</source>
        <translation>選取一個目錄</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>檔案操作設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>啟用</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>操作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>菜單文本</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>熱鍵</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>目標目錄</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>檔名方案：</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/General/fileops/translations/fileops_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="97"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>目標目錄早已存在</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="103"/>
        <source>Copying</source>
        <translation>正在復制</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="104"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="145"/>
        <source>Copying file %1/%2</source>
        <translation>復制檔案 %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="188"/>
        <source>Remove files</source>
        <translation>刪除檔案</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="189"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>你確認要從磁盤中刪除%n文件？</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>檔案操作插件</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>關於檔案操作插件</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Qmmp 檔案操作插件</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>修改熱鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>請按您想指定的組合鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Copy</source>
        <translation>復制</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="56"/>
        <location filename="../settingsdialog.cpp" line="136"/>
        <source>Remove</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="139"/>
        <source>New action</source>
        <translation>新動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="193"/>
        <source>Artist</source>
        <translation>藝術家</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="194"/>
        <source>Album</source>
        <translation>專輯</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="198"/>
        <source>Genre</source>
        <translation>流派</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="205"/>
        <source>Year</source>
        <translation>年代</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="199"/>
        <source>Comment</source>
        <translation>備註</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="196"/>
        <source>Track number</source>
        <translation>音軌編號</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="197"/>
        <source>Two-digit track number</source>
        <translation>兩位數音軌編號</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="200"/>
        <source>Composer</source>
        <translation>作曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="201"/>
        <source>Duration</source>
        <translation>持續時間</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="202"/>
        <source>Disc number</source>
        <translation>光槃編號</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="203"/>
        <source>File name</source>
        <translation>文件名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="204"/>
        <source>File path</source>
        <translation>文件路徑</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="206"/>
        <source>Condition</source>
        <translation>條件</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="222"/>
        <source>Choose a directory</source>
        <translation>選取一個目錄</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>檔案操作設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>啟用</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>操作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>菜單文本</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>熱鍵</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>目標目錄</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>檔名方案：</translation>
    </message>
</context>
</TS>
